"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.enablePersistence = exports.ReactQueryFirestoreProvider = exports.useFirestore = void 0;

var _react = _interopRequireDefault(require("react"));

var _reactQuery = require("react-query");

var _persistQueryClientExperimental = require("react-query/persistQueryClient-experimental");

var _createAsyncStoragePersistorExperimental = require("react-query/createAsyncStoragePersistor-experimental");

var _fastSafeStringify = _interopRequireDefault(require("fast-safe-stringify"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function createCtx() {
  const ctx = /*#__PURE__*/_react.default.createContext(undefined);

  function useCtx() {
    const c = _react.default.useContext(ctx);

    if (c === undefined) throw new Error("useCtx must be inside a Provider with a value");
    return c;
  }

  return [useCtx, ctx.Provider]; // 'as const' makes TypeScript infer a tuple
}

const [useFirestore, FirestoreProvider] = createCtx();
exports.useFirestore = useFirestore;
const queryClient = new _reactQuery.QueryClient();

const enablePersistence = storage => {
  const asyncStoragePersistor = (0, _createAsyncStoragePersistorExperimental.createAsyncStoragePersistor)({
    storage,
    serialize: _fastSafeStringify.default
  });
  (0, _persistQueryClientExperimental.persistQueryClient)({
    queryClient,
    persistor: asyncStoragePersistor
  });
};

exports.enablePersistence = enablePersistence;

const ReactQueryFirestoreProvider = ({
  children,
  reactQueryConfig,
  firestore
}) => {
  queryClient.setDefaultOptions(reactQueryConfig || {});
  return /*#__PURE__*/_react.default.createElement(FirestoreProvider, {
    value: {
      firestore
    }
  }, /*#__PURE__*/_react.default.createElement(_reactQuery.QueryClientProvider, {
    client: queryClient
  }, children));
};

exports.ReactQueryFirestoreProvider = ReactQueryFirestoreProvider;
//# sourceMappingURL=Provider.js.map