function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import { empty } from "./types";
/**
 * Collection cache
 *
 * This helps us keep track of which collections have been created.
 *
 * Whenever we edit a document, we then check the collection cache to see which collections we should also update.
 */

class CollectionCache {
  constructor() {
    _defineProperty(this, "collections", void 0);

    this.collections = {};
  }

  getKeysFromCollectionPath(path) {
    var _this$collections$pat, _this$collections$pat2;

    const isCollection = path.trim().split("/").filter(Boolean).length % 2 !== 0;

    if (!isCollection) {
      console.error(`[react-query-keys-from-collection-path] error: Passed a path that was not a collection to useCollection: ${path}.`);
    }

    return (_this$collections$pat = (_this$collections$pat2 = this.collections[path]) === null || _this$collections$pat2 === void 0 ? void 0 : _this$collections$pat2.map(({
      key
    }) => // if the queryString is undefined, take it out of the array
    key.filter(keyItem => typeof keyItem === "string")).filter(Boolean)) !== null && _this$collections$pat !== void 0 ? _this$collections$pat : empty.array;
  }

  addCollectionToCache(path, queryString) {
    var _this$collections$pat3;

    const collectionAlreadyExistsInCache = (_this$collections$pat3 = this.collections[path]) === null || _this$collections$pat3 === void 0 ? void 0 : _this$collections$pat3.some(({
      key
    }) => key[0] === path && key[1] === queryString);

    if (!collectionAlreadyExistsInCache) {
      var _this$collections$pat4;

      this.collections = { ...this.collections,
        [path]: [...((_this$collections$pat4 = this.collections[path]) !== null && _this$collections$pat4 !== void 0 ? _this$collections$pat4 : empty.array), {
          key: [path, queryString]
        }]
      };
    }

    return this.collections;
  }

}

export const collectionCache = new CollectionCache();
//# sourceMappingURL=Cache.js.map