import React from "react";
import { QueryClient, QueryClientProvider } from "react-query";
import { persistQueryClient } from "react-query/persistQueryClient-experimental";
import { createAsyncStoragePersistor } from "react-query/createAsyncStoragePersistor-experimental";
import stringify from "fast-safe-stringify";

function createCtx() {
  const ctx = /*#__PURE__*/React.createContext(undefined);

  function useCtx() {
    const c = React.useContext(ctx);
    if (c === undefined) throw new Error("useCtx must be inside a Provider with a value");
    return c;
  }

  return [useCtx, ctx.Provider]; // 'as const' makes TypeScript infer a tuple
}

const [useFirestore, FirestoreProvider] = createCtx();
const queryClient = new QueryClient();

const enablePersistence = storage => {
  const asyncStoragePersistor = createAsyncStoragePersistor({
    storage,
    serialize: stringify
  });
  persistQueryClient({
    queryClient,
    persistor: asyncStoragePersistor
  });
};

const ReactQueryFirestoreProvider = ({
  children,
  reactQueryConfig,
  firestore
}) => {
  queryClient.setDefaultOptions(reactQueryConfig || {});
  return /*#__PURE__*/React.createElement(FirestoreProvider, {
    value: {
      firestore
    }
  }, /*#__PURE__*/React.createElement(QueryClientProvider, {
    client: queryClient
  }, children));
};

export { useFirestore, ReactQueryFirestoreProvider, enablePersistence };
//# sourceMappingURL=Provider.js.map