import { UseQueryOptions, UseInfiniteQueryOptions } from "react-query";
import { FieldPath, WhereFilterOp, QueryDocumentSnapshot } from "@firebase/firestore-types";
export declare const empty: {
    object: {};
    array: never[];
    function: () => void;
};
export declare type AllowType<O extends unknown, Allowed> = {
    [K in keyof O]: O[K] | Allowed;
};
export declare type Document<T = unknown> = T & {
    id: string;
    exists?: boolean;
    hasPendingWrites?: boolean;
    __snapshot?: QueryDocumentSnapshot;
};
export declare type Options<Doc, TData> = UseQueryOptions<Doc, Error, TData>;
export declare type InfiniteOptions<Doc, TData> = UseInfiniteQueryOptions<Doc, Error, TData>;
export declare type ListenerReturnType<Doc extends Document = Document> = {
    initialData: Doc;
    unsubscribe: () => void;
};
export declare type Collections = {
    [path: string]: {
        key: [string, string | undefined];
    }[];
};
declare type KeyHack = string & Record<string, unknown>;
export declare type OrderByArray<Doc extends Document = Document, Key = keyof Doc> = [
    Key | FieldPath | KeyHack,
    "asc" | "desc"
];
export declare type OrderByItem<Doc extends Document = Document, Key = keyof Doc> = OrderByArray<Doc> | Key | KeyHack;
export declare type OrderByType<Doc extends Document = Document> = OrderByItem<Doc> | OrderByArray<Doc>[];
export declare type WhereItem<Doc extends Document = Document, Key = keyof Doc> = [
    Key | FieldPath | KeyHack,
    WhereFilterOp,
    unknown
];
export declare type WhereArray<Doc extends Document = Document> = WhereItem<Doc>[];
export declare type WhereType<Doc extends Document = Document> = WhereItem<Doc> | WhereArray<Doc>;
export declare type CollectionQueryType<Doc extends Document = Document> = {
    limit?: number;
    orderBy?: OrderByType<Doc>;
    where?: WhereType<Doc>;
    isCollectionGroup?: boolean;
    /**
     * For now, this can only be a number, since it has to be JSON serializable.
     *
     * **TODO** allow DocumentSnapshot here too. This will probably be used with a useStaticCollection hook in the future.
     */
    startAt?: number;
    /**
     * For now, this can only be a number, since it has to be JSON serializable.
     *
     * **TODO** allow DocumentSnapshot here too. This will probably be used with a useStaticCollection hook in the future.
     */
    endAt?: number;
    /**
     * For now, this can only be a number, since it has to be JSON serializable.
     *
     * **TODO** allow DocumentSnapshot here too. This will probably be used with a useStaticCollection hook in the future.
     */
    startAfter?: number;
    /**
     * For now, this can only be a number, since it has to be JSON serializable.
     *
     * **TODO** allow DocumentSnapshot here too. This will probably be used with a useStaticCollection hook in the future.
     */
    endBefore?: number;
};
export declare type Optional<T, K extends keyof T> = Pick<Partial<T>, K> & Omit<T, K>;
export interface Storage {
    getItem: (key: string) => Promise<string | null>;
    setItem: (key: string, value: string) => Promise<void>;
    removeItem: (key: string) => Promise<void>;
}
export {};
