import { CollectionQueryType, Document, Options, Optional } from "./types";
/**
 * Call a Firestore Collection
 * @template Doc
 * @param path String if the document is ready. If it's not ready yet, pass `null`, and the request won't start yet.
 * @param [query] - Dictionary with options to query the collection.
 * @param [options] - takes any of useQuery options.
 */
export declare const useCollection: <Data, TransData = unknown>(path?: string | undefined, options?: Options<Document<Data>[], Optional<Document<TransData>, "id">[]> | undefined, query?: (CollectionQueryType<Document<Data>> & {
    ignoreFirestoreDocumentSnapshotField?: boolean | undefined;
}) | undefined) => {
    data: Optional<Document<TransData>, "id">[] | undefined;
    status: "error" | "idle" | "loading" | "success";
    error: Error | null;
    add: (newData: Data | Data[], subPath?: string | undefined) => Promise<Document<Data>[]>;
    setCache: (cachedData: TransData[]) => void;
    fetchNextPage: () => Promise<void>;
    isFetchingNextPage: boolean;
    hasNextPage: boolean;
    /**
     * A function that, when called, unsubscribes the Firestore listener.
     *
     * The function can be null, so make sure to check that it exists before calling it.
     *
     * Note: This is not necessary to use. `useCollection` already unmounts the listener for you. This is only intended if you want to unsubscribe on your own.
     */
    unsubscribe: (() => void) | null;
};
