import { DocumentData, QueryDocumentSnapshot } from "@firebase/firestore-types";
import { CollectionQueryType, Document, InfiniteOptions } from "./types";
/**
 * Call a Firestore Collection
 * @template Doc
 * @param path String if the document is ready. If it's not ready yet, pass `undefined`, and the request won't start yet.
 * @param [options] - takes any of useQuery options.
 * @param [query] - Dictionary with options to query the collection.
 */
export declare const useInfiniteCollection: <Data, TransData extends Data = Data>(path?: string | undefined, options?: InfiniteOptions<{
    data: Document<Data>[];
    lastDoc?: QueryDocumentSnapshot<DocumentData> | undefined;
}, {
    data: Document<TransData>;
}> | undefined, query?: CollectionQueryType<Document<Data>> | undefined) => {
    data: (Document<TransData> extends readonly (infer InnerArr)[] ? InnerArr : Document<TransData>)[] | undefined;
    status: "error" | "idle" | "loading" | "success";
    error: Error | null;
    add: (newData: Data | Data[], subPath?: string | undefined) => Promise<Document<Data>[]>;
    fetchNextPage: (options?: import("react-query").FetchNextPageOptions | undefined) => Promise<import("react-query").InfiniteQueryObserverResult<{
        data: Document<TransData>;
    }, Error>>;
    hasNextPage: boolean | undefined;
    isFetchingNextPage: boolean;
    /**
     * A function that, when called, unsubscribes the Firestore listener.
     *
     * The function can be null, so make sure to check that it exists before calling it.
     *
     * Note: This is not necessary to use. `useCollection` already unmounts the listener for you. This is only intended if you want to unsubscribe on your own.
     */
    unsubscribe: (() => void) | null;
};
